@@ -266,8 +266,8 @@ gboolean a_dialog_new_waypoint ( GtkWindow *parent, gchar **dest, VikWaypoint *w
     store = gtk_list_store_new(3, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_STRING);
     symbolentry = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
     gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(symbolentry), 6);
-    g_signal_connect(symbolentry, "changed",
-                   G_CALLBACK(symbol_entry_changed_cb), store);
+
+    g_signal_connect(symbolentry, "changed", G_CALLBACK(symbol_entry_changed_cb), store);
     gtk_list_store_append (store, &iter);
     gtk_list_store_set (store, &iter, 0, NULL, 1, NULL, 2, _("(none)"), -1);
     a_populate_sym_list(store);
@@ -709,7 +709,7 @@ void a_dialog_about ( GtkWindow *parent )
   const gchar *program_name = PACKAGE_NAME;
   const gchar *version = VIKING_VERSION;
   const gchar *website = VIKING_URL;
-  const gchar *copyright = "2003-2008, Evan Battaglia";
+  const gchar *copyright = "2003-2008, Evan Battaglia\n2008-2010, Viking's contributors";
   const gchar *comments = _("GPS Data and Topo Analyzer, Explorer, and Manager.");
   const gchar *license = _("This program is free software; you can redistribute it and/or modify "
 			"it under the terms of the GNU General Public License as published by "
