@@ -37,6 +37,7 @@ static const char *menu_xml =
 	"      <menuitem action='DeleteAll'/>"
 	"      <separator/>"
 	"      <menuitem action='MapCacheFlush'/>"
+	"      <menuitem action='SetDefaultLocation'/>"
 	"      <menuitem action='Preferences'/>"
 	"    </menu>"
 	"    <menu action='View'>"
@@ -46,6 +47,7 @@ static const char *menu_xml =
 #endif
 	"      <menuitem action='ModeMercator'/>"
 	"      <separator/>"
+	"      <menuitem action='GotoDefaultLocation'/>"
 	"      <menuitem action='GotoSearch'/>"
 	"      <menuitem action='GotoLL'/>"
 	"      <menuitem action='GotoUTM'/>"
@@ -70,6 +72,14 @@ static const char *menu_xml =
 	"        <menuitem action='Zoom32'/>"
 	"        <menuitem action='Zoom64'/>"
 	"        <menuitem action='Zoom128'/>"
+	"        <menuitem action='Zoom256'/>"
+	"        <menuitem action='Zoom512'/>"
+	"        <menuitem action='Zoom1024'/>"
+	"        <menuitem action='Zoom2048'/>"
+	"        <menuitem action='Zoom4096'/>"
+	"        <menuitem action='Zoom8192'/>"
+	"        <menuitem action='Zoom16384'/>"
+	"        <menuitem action='Zoom32768'/>"
 	"      </menu>"
         "      <menu action='SetPan'>"
         "          <menuitem action='PanNorth'/>"
@@ -91,6 +101,7 @@ static const char *menu_xml =
 	"      <menuitem action='Ruler'/>"
 	"    </menu>"
 	"    <menu action='Help'>"
+	"      <menuitem action='HelpEntry'/>"
 	"      <menuitem action='About'/>"
 	"    </menu>"
 	"  </menubar>"
@@ -111,6 +122,7 @@ static const char *menu_xml =
 	"      <separator/>"
 	"    </placeholder>"
 	"    <placeholder name='ViewToolItems'>"
+	"      <toolitem action='GotoDefaultLocation'/>"
 	"      <toolitem action='GotoSearch'/>"
 	"      <separator/>"
 	"    </placeholder>"
