@@ -24,6 +24,11 @@ void a_preferences_show_window(GtkWindow *parent);
 
 VikLayerParamData *a_preferences_get(const gchar *key);
 
+/* Allow preferences to be manipulated externally */
+void a_preferences_run_setparam ( VikLayerParamData data, VikLayerParam *params );
+
+/* TRUE on success */
+gboolean a_preferences_save_to_file();
 
 
 #endif
