@@ -460,7 +460,8 @@ void vik_layer_post_read ( VikLayer *layer, VikViewport *vp, gboolean from_file
 
 static gboolean layer_properties_factory ( VikLayer *vl, VikViewport *vp )
 {
-  switch ( a_uibuilder_properties_factory ( VIK_GTK_WINDOW_FROM_WIDGET(vp),
+  switch ( a_uibuilder_properties_factory ( _("Layer Properties"),
+					    VIK_GTK_WINDOW_FROM_WIDGET(vp),
 					    vik_layer_interfaces[vl->type]->params,
 					    vik_layer_interfaces[vl->type]->params_count,
 					    vik_layer_interfaces[vl->type]->params_groups,
